@@ -49,8 +49,8 @@ account_map = {
     'Stage': ['stage', 'us-west-1'],
     'HireEz-PROD2': ['prod2', 'us-west-2'],
     'prod': ['prod', 'us-west-1'],
-    'HireEz-TEST': ['test1', 'us-west-1'],
-    'HireEz-STAGE': ['stage1', 'us-west-1'],
+    'HireEz-TEST1': ['test1', 'us-west-1'],
+    'HireEz-STAGE1': ['stage1', 'us-west-1'],
     'Test': ['test', 'us-west-1'],
     'HireEz-OPS2': ['ops2', 'us-west-2'],
     'HireEz-PROD1': ['prod1', 'us-west-1']
@@ -77,6 +77,9 @@ def main():
     parser.add_argument('-g',
         action='store_true',
         help='aws sso logout.')
+    parser.add_argument('-i',
+        action='store_true',
+        help='check aws session.')
 #    parser_sso = subparsers.add_parser('sso')
 #    parser_sso_sub = parser_sso.add_subparsers()
 #    parser_sso_config = parser_sso_sub.add_parser('config',
@@ -108,8 +111,7 @@ def main():
     parser_env_load.set_defaults(func=_env_load)
 
 
-    parser_tf = subparsers.add_parser('tf',
-                        help='terraform command, eg: init plan apply destroy')
+    parser_tf = subparsers.add_parser('tf')
     parser_tf.add_argument('cmd', nargs='*',
                         help='terraform command, eg: init plan apply destroy')
     parser_tf.set_defaults(func=_tf_cmd)
@@ -182,7 +184,7 @@ def main():
         parser.print_help()
     if len(sys.argv) == 3 and sys.argv[1] == '-s':
         _sso_switch(sys.argv[2])
-    if len(sys.argv) == 2 and sys.argv[1] in ('-l', '-c', '-s'):
+    if len(sys.argv) == 2 and sys.argv[1] in ('-l', '-c', '-s', '-g', '-i'):
         if sys.argv[1] == '-l':
             _sso_login()
         if sys.argv[1] == '-c':
@@ -191,6 +193,8 @@ def main():
             _sso_switch()
         if sys.argv[1] == '-g':
             _sso_logout()
+        if sys.argv[1] == '-i':
+            _sso_session_check()
     if len(sys.argv) == 2 and sys.argv[1] in subparsers.choices:
         print(subparsers.choices[sys.argv[1]].format_help())
 
@@ -292,6 +296,11 @@ def _sso_logout():
     profile = _add_prefix(_select_profile(select_one))
     _spawn_cli_for_logout(profile)
 
+def _sso_session_check():
+    subprocess.run(['aws', 'sts', 'get-caller-identity'],
+                       stderr=sys.stderr,
+                       stdout=sys.stdout,
+                       check=True)
 
 def _sso_login():
     _validate_awscli()
